==> bplan-base-globals-1.1.0-0b4347.zip: lang/hu/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'hu',
    'language' => 'Magyar',
    'locale' => 'hu_HU',

    'currency.decimals'        => "0",
    'currency.format.string'   => ':value Ft',
    'currency.format.negative' => '-:value Ft',
    'currency.iso4217.alpha'   => 'HUF',
    'currency.iso4217.numeric' => 348,
    'currency.name'            => 'Forint',
    'currency.subunit.divisor' => 1,
    'currency.subunit.name'    => '',
    'currency.subunit.symbol'  => '',
    'currency.symbol'          => 'Ft',

    'date.format'       => 'Y. m. d.',
    'datetime.format'   => 'Y. m. d. H:i',
    'datetime.format+'  => 'Y. m. d. H:i:s',
    'datetime.format-+' => 'Y. m. d. H:i',
    'datetime.format++' => 'Y. m. d. H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktiválás',
    'action.add'           => 'Hozzáadás',
    'action.cancel'        => 'Mégse',
    'action.cancel-upload' => 'Feltöltés megszakítása',
    'action.change'        => 'Módosítás',
    'action.close'         => 'Bezárás',
    'action.confirm'       => 'Megerősítés',
    'action.deactivate'    => 'Deaktiválás',
    'action.delete'        => 'Törlés',
    'action.edit'          => 'Szerkesztés',
    'action.import'        => 'Importálás',
    'action.print'         => 'Nyomtatás',
    'action.save'          => 'Mentés',
    'action.search'        => 'Keresés',
    'action.sync'          => 'Szinkronizálás',
    'action.upload'        => 'Fájl feltöltése',
    'action.verify'        => 'Ellenőrzés',
    'action.view'          => 'Megtekintés',

    'languages' => [
        'bg' => 'Bolgár',
        'de' => 'Német',
        'en' => 'Angol',
        'es' => 'Spanyol',
        'fr' => 'Francia',
        'hu' => 'Magyar',
        'it' => 'Olasz',
        'lt' => 'Litván',
        'pl' => 'Lengyel',
        'ro' => 'Román',
        'ru' => 'Orosz',
        'tr' => 'Török',
        'uk' => 'Ukrán',
    ],

    'option.yes' => 'Igen',
    'option.no'  => 'Nem',

    'required-hint'   => 'A megjelölt mezők (<span class="required-marker">:marker</span>) kitöltése kötelező',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Kérjük, válasszon -- ',

    'status.active'   => 'Aktív',
    'status.expired'  => 'Lejárt',
    'status.inactive' => 'Inaktív',
    'status.invalid'  => 'Érvénytelen',
    'status.loading'  => 'Betöltés...',
    'status.not-set'  => 'Nincs beállítva',
    'status.valid'    => 'Érvényes',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/hu/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'hu',
    'language' => 'Magyar',
    'locale' => 'hu_HU',

    'currency.decimals'        => "0",
    'currency.format.string'   => ':value Ft',
    'currency.format.negative' => '-:value Ft',
    'currency.iso4217.alpha'   => 'HUF',
    'currency.iso4217.numeric' => 348,
    'currency.name'            => 'Forint',
    'currency.subunit.divisor' => 1,
    'currency.subunit.name'    => '',
    'currency.subunit.symbol'  => '',
    'currency.symbol'          => 'Ft',

    'date.format'       => 'Y. m. d.',
    'datetime.format'   => 'Y. m. d. H:i',
    'datetime.format+'  => 'Y. m. d. H:i:s',
    'datetime.format-+' => 'Y. m. d. H:i',
    'datetime.format++' => 'Y. m. d. H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktiválás',
    'action.add'           => 'Hozzáadás',
    'action.cancel'        => 'Mégse',
    'action.cancel-upload' => 'Feltöltés megszakítása',
    'action.change'        => 'Módosítás',
    'action.close'         => 'Bezárás',
    'action.confirm'       => 'Megerősítés',
    'action.deactivate'    => 'Deaktiválás',
    'action.delete'        => 'Törlés',
    'action.edit'          => 'Szerkesztés',
    'action.import'        => 'Importálás',
    'action.print'         => 'Nyomtatás',
    'action.save'          => 'Mentés',
    'action.search'        => 'Keresés',
    'action.sync'          => 'Szinkronizálás',
    'action.upload'        => 'Fájl feltöltése',
    'action.verify'        => 'Ellenőrzés',
    'action.view'          => 'Megtekintés',

    'languages' => [
        'bg' => 'Bolgár',
        'de' => 'Német',
        'en' => 'Angol',
        'es' => 'Spanyol',
        'fr' => 'Francia',
        'hu' => 'Magyar',
        'it' => 'Olasz',
        'lt' => 'Litván',
        'pl' => 'Lengyel',
        'ro' => 'Román',
        'ru' => 'Orosz',
        'tr' => 'Török',
        'uk' => 'Ukrán',
    ],

    'option.yes' => 'Igen',
    'option.no'  => 'Nem',

    'required-hint'   => 'A megjelölt mezők (<span class="required-marker">:marker</span>) kitöltése kötelező',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Nincsenek elérhető opciók',
    'select-option.please-select'        => ' -- Kérjük, válasszon -- ',

    'status.active'   => 'Aktív',
    'status.expired'  => 'Lejárt',
    'status.inactive' => 'Inaktív',
    'status.invalid'  => 'Érvénytelen',
    'status.loading'  => 'Betöltés...',
    'status.not-set'  => 'Nincs beállítva',
    'status.valid'    => 'Érvényes',

];
